/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach;

import de.ozgcloud.vorgang.common.GrpcObject;
import de.ozgcloud.vorgang.common.GrpcProperty;

public class GrpcPostfachAddressTestFactory {

	public final static int ADDRESS_TYPE = 1;
	public static final String ADDRESS_VERSION = "1.0";
	public static final String POSTFACH_TYPE = "postfachType";

	public static final String FIELD_POSTFACH_ID = "postfachId";

	public static GrpcPostfachAddress create() {
		return createBuilder().build();
	}

	public static GrpcPostfachAddress.Builder createBuilder() {
		return GrpcPostfachAddress.newBuilder()
				.setType(ADDRESS_TYPE)
				.setIdentifier(createIdentifier())
				.setVersion(ADDRESS_VERSION)
				.setServiceKontoType(POSTFACH_TYPE);

	}

	public static GrpcObject createIdentifier() {
		return createIdentifier(GrpcPostfachMailTestFactory.POSTFACH_ID);
	}

	public static GrpcObject createIdentifier(String postfachId) {
		return GrpcObject.newBuilder()
				.addProperty(GrpcProperty.newBuilder()
						.setName(FIELD_POSTFACH_ID)
						.addValue(postfachId)
						.build())
				.build();
	}
}