/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach;

import java.util.List;
import java.util.UUID;

public class GrpcPostfachMailTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final String VORGANG_ID = UUID.randomUUID().toString();
	public static final String REFERENCED_NACHRICHT_ID = UUID.randomUUID().toString();
	public static final String POSTFACH_ID = UUID.randomUUID().toString();
	public static final String CREATED_AT = "2020-04-01T10:30:10Z";
	public static final String CREATED_BY = UUID.randomUUID().toString();
	public static final String SENT_AT = "2020-04-01T11:30:10Z";
	public static final String MESSAGE_CODE = "message.code";
	public static final GrpcDirection DIRECTION = GrpcDirection.IN;
	private static final String SUBJECT = "Test Subject";
	public static final String MAIL_BODY = "Body\nString";
	public static final String REPLY_OPTION = "MANDATORY";
	public static final String ATTACHMENT_FILE_ID = "21";
	public static final List<String> ATTACHMENTS = List.of(ATTACHMENT_FILE_ID);

	public static GrpcPostfachMail create() {
		return createBuilder().build();
	}

	public static GrpcPostfachMail.Builder createBuilder() {
		return GrpcPostfachMail.newBuilder()
				.setId(ID)
				.setReferencedNachricht(REFERENCED_NACHRICHT_ID)
				.setVorgangId(VORGANG_ID)
				.setPostfachAddress(GrpcPostfachAddressTestFactory.create())
				.setCreatedAt(CREATED_AT)
				.setCreatedBy(CREATED_BY)
				.setSentAt(SENT_AT)
				.setSentSuccessful(true)
				.setMessageCode(MESSAGE_CODE)
				.setDirection(DIRECTION)
				.setSubject(SUBJECT)
				.setMailBody(MAIL_BODY)
				.setReplyOption(REPLY_OPTION)
				.addAllAttachment(ATTACHMENTS);
	}
}