/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.antragraum;

import java.time.ZonedDateTime;
import java.time.temporal.ChronoField;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;

import de.ozgcloud.nachrichten.postfach.PostfachNachricht;

@Mapper(collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
interface AntragraumNachrichtMapper {

	@Mapping(target = "trustLevelBytes", ignore = true)
	@Mapping(target = "vorgangNummerBytes", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "answeredAt", ignore = true)
	@Mapping(target = "answeredAtBytes", ignore = true)
	@Mapping(target = "idBytes", ignore = true)
	@Mapping(target = "sentAtBytes", ignore = true)
	@Mapping(target = "statusBytes", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "vorgangIdBytes", ignore = true)
	@Mapping(target = "vorgangNameBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "sentAt", source = "sentAt", dateFormat = "yyyy-MM-dd'T'HH:mm:ss")
	GrpcRueckfrageHead toGrpc(RueckfrageHead rueckfrage);

	@Mapping(target = "referencedNachricht", ignore = true)
	@Mapping(target = "mailBody", source = "answerText")
	@Mapping(target = "attachments", source = "attachmentFileIdList")
	@Mapping(target = "createdAt", ignore = true)
	@Mapping(target = "createdBy", ignore = true) // FIXME
	@Mapping(target = "direction", constant = "IN")
	@Mapping(target = "id", ignore = true)
	@Mapping(target = "messageCode", ignore = true)
	@Mapping(target = "messageId", source = "rueckfrageId")
	@Mapping(target = "postfachAddress", ignore = true)
	@Mapping(target = "replyOption", constant = "FORBIDDEN")
	@Mapping(target = "sentSuccessful", constant = "true")
	@Mapping(target = "subject", constant = "Antwort") // TODO klären
	@Mapping(target = "vorgangId", ignore = true)
	@Mapping(target = "sentAt", expression = "java(mapZonedDateTime(answer.getSentAt()))")
	PostfachNachricht fromRueckfrageAnswer(GrpcRueckfrageAnswer answer);

	default ZonedDateTime mapZonedDateTime(String sentAt) {
		if (StringUtils.isBlank(sentAt)) {
			return ZonedDateTime.now().with(ChronoField.MILLI_OF_SECOND, 0);
		}
		return ZonedDateTime.parse(sentAt);
	}

	@Mapping(target = "sentAtBytes", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "answerText", source = "mailBody")
	@Mapping(target = "answerTextBytes", ignore = true)
	@Mapping(target = "rueckfrageId", source = "id")
	@Mapping(target = "rueckfrageIdBytes", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "attachmentFileIdList", source = "attachments")
	GrpcRueckfrageAnswer toRueckfrageAnswer(PostfachNachricht answer);
}
