/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.antragraum;

import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Optional;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.nachrichten.common.vorgang.Vorgang;
import de.ozgcloud.nachrichten.postfach.PostfachNachricht;

@Mapper(collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, //
		unmappedTargetPolicy = ReportingPolicy.WARN, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
interface RueckfrageMapper {

	final DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd'T'HH:mm:ssX");

	@Mapping(target = "accessible", ignore = true)
	@Mapping(target = "trustLevel", ignore = true)
	@Mapping(target = "vorgangNummer", ignore = true)
	@Mapping(target = "answeredAt", ignore = true)
	@Mapping(target = "status", ignore = true)
	@Mapping(target = "vorgangName", ignore = true)
	RueckfrageHead fromPostfachNachricht(PostfachNachricht postfachNachricht);

	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "removeAnswers", ignore = true)
	@Mapping(target = "answeredAt", expression = "java(setAnsweredAt(firstAnswerSentAt))")
	@Mapping(target = "answeredAtBytes", ignore = true)
	@Mapping(target = "idBytes", ignore = true)
	@Mapping(target = "sentAtBytes", ignore = true)
	@Mapping(target = "statusBytes", ignore = true)
	@Mapping(target = "trustLevelBytes", ignore = true)
	@Mapping(target = "vorgangIdBytes", ignore = true)
	@Mapping(target = "vorgangNummerBytes", ignore = true)
	@Mapping(target = "accessible", ignore = true)
	@Mapping(target = "status", expression = "java(setStatus(firstAnswerSentAt))")
	@Mapping(target = "textBytes", ignore = true)
	@Mapping(target = "trustLevel", source = "vorgang.trustLevel")
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "vorgangName", source = "vorgang.name")
	@Mapping(target = "vorgangNameBytes", ignore = true)
	@Mapping(target = "vorgangNummer", source = "vorgang.nummer")
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "answersBuilderList", ignore = true)
	@Mapping(target = "answersList", ignore = true)
	@Mapping(target = "answersOrBuilderList", ignore = true)
	@Mapping(target = "attachmentFileIdList", source = "rueckfrage.attachments")
	@Mapping(target = "sentAt", source = "rueckfrage.sentAt", dateFormat = "yyyy-MM-dd'T'HH:mm:ss")
	@Mapping(target = "id", source = "rueckfrage.id")
	@Mapping(target = "text", source = "rueckfrage.mailBody")
	GrpcRueckfrage toRueckfrage(Optional<ZonedDateTime> firstAnswerSentAt, Vorgang vorgang, PostfachNachricht rueckfrage);

	default String setVorgangName(Vorgang vorgang) {
		return vorgang.getName();
	}

	default String setAnsweredAt(Optional<ZonedDateTime> firstAnswerSentAt) {
		return firstAnswerSentAt.map(formatter::format).orElseGet(() -> StringUtils.EMPTY);
	}

	default String setStatus(Optional<ZonedDateTime> firstAnswerSentAt) {
		return firstAnswerSentAt.map(answeredAt -> RueckfrageStatus.ANSWERED.name()).orElseGet(RueckfrageStatus.NEW::name);
	}
}