/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.antragraum;

import java.util.Arrays;

import lombok.Getter;

@Getter
enum TrustLevel {

	LEVEL_1("STORK-QAA-Level-1"),
	LEVEL_2("STORK-QAA-Level-2"),
	LEVEL_3("STORK-QAA-Level-3"),
	LEVEL_4("STORK-QAA-Level-4");

	private final String value;
	private final int intValue;

	TrustLevel(String value) {
		this.value = value;
		this.intValue = extractIntValue();
	}

	private int extractIntValue() {
		return Integer.parseInt(value.substring(value.length() - 1));
	}

	public static TrustLevel fromString(String value) {
		return Arrays.stream(TrustLevel.values()).filter(trustLevel -> trustLevel.getValue().equals(value)).findFirst()
				.orElseThrow(() -> new IllegalArgumentException("Unknown TrustLevel: '" + value + "'"));
	}
}