/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.common.grpc;

import java.util.UUID;

import org.apache.logging.log4j.ThreadContext;

import de.ozgcloud.common.grpc.GrpcUtil;
import io.grpc.CallOptions;
import io.grpc.Channel;
import io.grpc.ClientCall;
import io.grpc.ClientInterceptor;
import io.grpc.ForwardingClientCall.SimpleForwardingClientCall;
import io.grpc.Metadata;
import io.grpc.MethodDescriptor;

public class NachrichtenCallContextAttachingInterceptor implements ClientInterceptor {

	static final String REQUEST_ID_KEY = "requestId";

	public static final String NACHRICHTEN_MANAGER_CLIENT_NAME = "OzgCloud_NachrichtenManager";
	public static final String NACHRICHTEN_MANAGER_SENDER_USER_ID = "system-nachrichten_manager-sender";

	// <A> = Request, <B> = Response
	@Override
	public <A, B> ClientCall<A, B> interceptCall(MethodDescriptor<A, B> method, CallOptions callOptions, Channel next) {
		return new CallContextAttachingClientCall<>(next.newCall(method, callOptions));
	}

	final class CallContextAttachingClientCall<A, B> extends SimpleForwardingClientCall<A, B> {

		CallContextAttachingClientCall(ClientCall<A, B> delegate) {
			super(delegate);
		}

		@Override
		public void start(Listener<B> responseListener, Metadata headers) {
			headers.merge(buildCallContextMetadata());
			super.start(responseListener, headers);
		}

		Metadata buildCallContextMetadata() {
			var metadata = new Metadata();

			metadata.put(GrpcUtil.HEADER_KEY_USER_ID, NACHRICHTEN_MANAGER_SENDER_USER_ID.getBytes());
			metadata.put(GrpcUtil.HEADER_KEY_CLIENT_NAME, NACHRICHTEN_MANAGER_CLIENT_NAME.getBytes());
			metadata.put(GrpcUtil.HEADER_KEY_REQUEST_ID, getRequestId());

			return metadata;
		}

		byte[] getRequestId() {
			return ThreadContext.getContext().getOrDefault(REQUEST_ID_KEY, UUID.randomUUID().toString()).getBytes();
		}

	}

}
