/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.common.vorgang;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.vorgang.vorgang.GrpcPostfachAddress;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangHead;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangWithEingang;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN)
interface NachrichtenVorgangMapper {

	@Mapping(target = "trustLevel", source = "vorgangWithEingang.header.serviceKonto.trustLevel")
	@Mapping(target = "postfachId", expression = "java(getPostfachId(vorgangWithEingang.getHeader()))")
	Vorgang fromVorgangWithEingang(GrpcVorgangWithEingang vorgangWithEingang);

	default String getPostfachId(GrpcVorgangHead head) {
		return head.getServiceKonto().getPostfachAddressesList().stream()
				.map(this::getPostfachId).findFirst()
				.orElse(StringUtils.EMPTY);
	}

	default String getPostfachId(GrpcPostfachAddress address) {
		return address.getIdentifier().getPropertyList().stream()
				.filter(prop -> Vorgang.POSTFACH_ID_FIELD.equals(prop.getName()))
				.map(prop -> prop.getValue(0))
				.findFirst()
				.orElse(StringUtils.EMPTY);
	}
}