/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.common.vorgang;

import java.util.Spliterator;
import java.util.Spliterators;
import java.util.stream.Stream;
import java.util.stream.StreamSupport;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.nachrichten.NachrichtenManagerConfiguration;
import de.ozgcloud.nachrichten.common.grpc.NachrichtenCallContextAttachingInterceptor;
import de.ozgcloud.nachrichten.postfach.FindVorgangIterator;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangWithEingangRequest;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangHeader;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc.VorgangServiceBlockingStub;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service(NachrichtenManagerConfiguration.NACHRICHTEN_VORGANG_REMOTE_SERVICE)
class VorgangRemoteService {

	@GrpcClient(NachrichtenManagerConfiguration.GRPC_VORGANG_MANAGER_NAME)
	private VorgangServiceBlockingStub vorgangServiceStub;

	@Autowired
	private NachrichtenVorgangMapper mapper;

	public Stream<String> findVorgangIds(String servicekontoType, String postfachId) {
		return buildStream(servicekontoType, postfachId).map(GrpcVorgangHeader::getId);
	}

	Stream<GrpcVorgangHeader> buildStream(String servicekontoType, String postfachId) {
		var findVorgangIterator = buildFindVorgangIterator(servicekontoType, postfachId);
		return StreamSupport.stream(Spliterators.spliteratorUnknownSize(findVorgangIterator, Spliterator.ORDERED), false);
	}

	FindVorgangIterator buildFindVorgangIterator(String servicekontoType, String postfachId) {
		return new FindVorgangIterator(getVorgangServiceStub(), servicekontoType, postfachId);
	}

	public Vorgang getVorgang(String vorgangId) {
		var response = getVorgangServiceStub().findVorgangWithEingang(buildFindVorgangWithEingangRequest(vorgangId));
		return mapper.fromVorgangWithEingang(response.getVorgangWithEingang());
	}

	VorgangServiceBlockingStub getVorgangServiceStub() {
		return vorgangServiceStub.withInterceptors(new NachrichtenCallContextAttachingInterceptor());
	}

	GrpcFindVorgangWithEingangRequest buildFindVorgangWithEingangRequest(String vorgangId) {
		return GrpcFindVorgangWithEingangRequest.newBuilder().setId(vorgangId).build();
	}
}