/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.email;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import de.ozgcloud.nachrichten.email.MailSendRequest.MailSendRequestBuilder;
import io.grpc.stub.StreamObserver;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
public class EmailGrpcService extends EmailServiceGrpc.EmailServiceImplBase {

	@Autowired
	private MailService mailService;

	@Value("${ozgcloud.notification.mail-from}")
	private String mailFrom;

	@Override
	public void sendEmail(GrpcSendEmailRequest grpcRequest, StreamObserver<GrpcSendEmailResponse> responseObserver) {
		createSendMailRequests(grpcRequest).forEach(mailService::sendMail);
		responseObserver.onNext(GrpcSendEmailResponse.newBuilder().build());
		responseObserver.onCompleted();
	}

	private List<MailSendRequest> createSendMailRequests(GrpcSendEmailRequest grpcRequest) {
		var subject = grpcRequest.getSubject();
		var body = grpcRequest.getBody();
		return grpcRequest.getRecipientsList().stream()
				.map(this::prepareMailSendRequest)
				.map(builder -> builder.subject(subject).body(body).build())
				.toList();
	}

	private MailSendRequestBuilder prepareMailSendRequest(GrpcRecipient recipient) {
		var mailRecipient = MailRecipient.builder().firstName(recipient.getFirstName()).lastName(recipient.getLastName()).email(recipient.getEmail())
				.build();
		return MailSendRequest.builder().fromAddress(mailFrom).toAddress(mailRecipient);
	}
}
