/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.info;

import jakarta.annotation.PostConstruct;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Service;

import de.ozgcloud.nachrichten.NachrichtenManagerProperties;
import de.ozgcloud.nachrichten.antragraum.AntragraumProperties;
import de.ozgcloud.nachrichten.postfach.PostfachAddress;
import de.ozgcloud.nachrichten.postfach.PostfachException;
import de.ozgcloud.nachrichten.postfach.PostfachMessageCode;
import de.ozgcloud.nachrichten.postfach.PostfachNachricht;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@RequiredArgsConstructor
@ConditionalOnProperty(AntragraumProperties.PROPERTY_ANTRAGSRAUM_URL)
public class InfoManagerService {

	private final InfoManagerRemoteService infomanagerRemoteService;
	private final NachrichtenManagerProperties nachrichtenManagerProperties;

	@PostConstruct
	void logInitalization() {
		LOG.info("Starting Info-Manager Service");
	}

	public void notifyInfoManager(PostfachNachricht postfachNachricht) {
		try {
			infomanagerRemoteService.sendNotification(builInfomanagerRequest(postfachNachricht));
		} catch (RuntimeException e) {
			throw new PostfachException("Error while sending notification to Antragsraum", PostfachMessageCode.PROCESS_FAILED_MESSAGE_CODE, e);
		}
	}

	InfoManagerRequest builInfomanagerRequest(PostfachNachricht postfachNachricht) {
		return InfoManagerRequest.builder()
				.nachrichtId(postfachNachricht.getId())
				.vorgangId(postfachNachricht.getVorgangId())
				.postfachId(getPostfachId(postfachNachricht.getPostfachAddress()))
				.nachrichtenManagerUrl(nachrichtenManagerProperties.getAddress())
				.build();
	}

	String getPostfachId(@NonNull PostfachAddress address) {
		return address.getIdentifier().getStringRepresentation();
	}
}
