/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach;

import java.util.Map;
import java.util.Optional;
import java.util.stream.Stream;

import de.ozgcloud.nachrichten.file.AttachmentFile;

//Temporally replacement for usign GRPC Api
public interface PersistPostfachNachrichtService {

	void persistNachricht(Optional<String> userId, PostfachNachricht nachricht);

	Stream<Map<String, Object>> findByVorgangAsMap(String vorgangId);

	Optional<Map<String, Object>> findById(String nachrichtId);

	void patch(String postfachMailId, Map<String, Object> propertyMap);

	Map<String, Object> getById(String itemId);

	// TODO use file id as soon it is available
	String persistAttachment(String vorgangId, AttachmentFile attachment);

	Stream<PostfachNachricht> findRueckfragen(String servicekontoType, String postfachId);

	/**
	 * Persists the given answer
	 *
	 * @param answer       The given answer
	 * @param rueckfrageId The ID of the original Rueckfrage
	 * @return ID of the persisted command
	 */
	String persistAnswer(String rueckfrageId, PostfachNachricht answer);

	/**
	 * Returns all Answers given for the Rueckfrage identified by id
	 *
	 * @param serviceKontoType Type of serviceKonto
	 * @param postfachId       ID of postfach
	 * @param rueckfrageId     ID of the Rueckfrage to load answers for.
	 * @return all Answers
	 */
	Stream<PostfachNachricht> findAnswers(String serviceKontoType, String postfachId, String rueckfrageId);
}
