/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.nachrichten.postfach.PostfachServiceGrpc.PostfachServiceImplBase;
import io.grpc.stub.StreamObserver;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
class PostfachGrpcService extends PostfachServiceImplBase {

	@Autowired
	private PostfachService service;
	@Autowired
	private PostfachNachrichtMapper mapper;
	@Autowired
	private PostfachMapper postfachMapper;

	@Autowired
	private GrpcPostfachNachrichtMapper nachrichtMapper;

	@Override
	public void saveNachrichtDraft(GrpcSaveNachrichtDraftRequest request, StreamObserver<GrpcSaveNachrichtDraftResponse> response) {
		service.saveDraft(request.getVorgangId(), nachrichtMapper.mapFromGrpc(request.getNachricht()));

		response.onNext(GrpcSaveNachrichtDraftResponse.newBuilder().build());
		response.onCompleted();
	}

	@Override
	public void sendPostfachMail(GrpcSendPostfachMailRequest req, StreamObserver<GrpcSendPostfachMailResponse> response) {
		service.sendMail(req.getCommandId(), req.getContext().getUser().getId(), mapper.fromGrpcMail(req.getMail()));

		response.onNext(GrpcSendPostfachMailResponse.newBuilder().build());
		response.onCompleted();
	}

	@Override
	public void findPostfachMail(GrpcFindPostfachMailRequest req, StreamObserver<GrpcFindPostfachMailResponse> response) {
		var responseBuilder = GrpcFindPostfachMailResponse.newBuilder();
		service.findById(req.getNachrichtId()).map(mapper::fromMap).ifPresent(responseBuilder::setNachricht);

		response.onNext(responseBuilder.build());
		response.onCompleted();
	}

	@Override
	public void findPostfachMails(GrpcFindPostfachMailsRequest req, StreamObserver<GrpcFindPostfachMailsResponse> response) {
		var mails = service.findByVorgang(req.getVorgangId()).map(mapper::fromMap).toList();

		response.onNext(GrpcFindPostfachMailsResponse.newBuilder().addAllMails(mails).build());
		response.onCompleted();
	}

	@Override
	public void resendPostfachMail(GrpcResendPostfachMailRequest request, StreamObserver<GrpcResendPostfachMailResponse> response) {
		service.resendMail(request.getCommandId(), request.getPostfachMailId());

		response.onNext(GrpcResendPostfachMailResponse.newBuilder().build());
		response.onCompleted();
	}

	@Override
	public void isPostfachConfigured(GrpcIsPostfachConfiguredRequest request, StreamObserver<GrpcIsPostfachConfiguredResponse> response) {
		response.onNext(GrpcIsPostfachConfiguredResponse.newBuilder().setIsConfigured(service.isPostfachConfigured()).build());
		response.onCompleted();
	}

	@Override
	public void getPostfachConfig(GrpcGetPostfachConfigRequest request, StreamObserver<GrpcGetPostfachConfigResponse> response) {
		response.onNext(buildGetPostfachConfigResponse());
		response.onCompleted();
	}

	GrpcGetPostfachConfigResponse buildGetPostfachConfigResponse() {
		var grpcPostfachs = service.getPostfachs().map(postfachMapper::toGrpc).toList();
		if (CollectionUtils.isEmpty(grpcPostfachs)) {
			return GrpcGetPostfachConfigResponse.newBuilder().setConfigured(false).build();
		}
		return GrpcGetPostfachConfigResponse.newBuilder().setConfigured(true).addAllPostfach(grpcPostfachs).build();
	}
}