/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid;

import java.io.InputStream;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Service;

import de.ozgcloud.nachrichten.file.AttachmentFile;
import de.ozgcloud.nachrichten.file.AttachmentFileService;
import de.ozgcloud.nachrichten.postfach.FileId;
import lombok.RequiredArgsConstructor;

@Service
@ConditionalOnProperty(prefix = "ozgcloud.bayernid", name = { "enabled" })
@RequiredArgsConstructor
public class BayernIdAttachmentService {

	private final AttachmentFileService attachmentFileService;

	public BayernIdAttachment getMessageAttachment(FileId fileId) {
		return buildBayernIdAttachment(attachmentFileService.getFile(fileId), attachmentFileService.getFileContent(fileId));
	}

	BayernIdAttachment buildBayernIdAttachment(AttachmentFile attachmentFile, InputStream attachmentContent) {
		return BayernIdAttachment.builder()
				.fileName(attachmentFile.getName())
				.contentType(attachmentFile.getContentType())
				.content(attachmentContent)
				.build();
	}

}
