/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid;

enum MailSendingResponseStatus {
	SUCCESS("0", "Nachricht wurde erfolgreich übernommen"),
	OK_KOMM_SCHEMA_ERROR("10", "Fehler im OK.KOMM-Schema"),
	OK_KOMM_INVALID_SCHEMA_PARAMETER("11", "Ungültige Parameter im OK.KOMM-Schema"),
	ERROR_IN_MESSAGE_SCHEMA("20", "Fehler im BSP-Nachrichtenschema"),
	INVALID_POSTKORB_ID("30", "Ungültiger Postkorb-Handle"),
	IMPROPER_MESSAGE_CONTENT("31", "Unzulässiger Nachrichteninhalt"),
	IMPROPER_MESSAGE_ATTACHMENT("32", "Unzulässiger Nachrichtenanhang"),
	TECHNICAL_ERROR("99", "Sonstiger technischer Fehler"),
	UNKNOWN("-1", "Unbekannte Server Antwort");

	private String schluessel;
	private String message;

	MailSendingResponseStatus(String schluessel, String message) {
		this.schluessel = schluessel;
		this.message = message;
	}

	public static MailSendingResponseStatus fromSchluessel(String schluessel) {
		return switch (schluessel) {
			case "0" -> MailSendingResponseStatus.SUCCESS;
			case "10" -> MailSendingResponseStatus.OK_KOMM_SCHEMA_ERROR;
			case "11" -> MailSendingResponseStatus.OK_KOMM_INVALID_SCHEMA_PARAMETER;
			case "20" -> MailSendingResponseStatus.ERROR_IN_MESSAGE_SCHEMA;
			case "30" -> MailSendingResponseStatus.INVALID_POSTKORB_ID;
			case "31" -> MailSendingResponseStatus.IMPROPER_MESSAGE_CONTENT;
			case "32" -> MailSendingResponseStatus.IMPROPER_MESSAGE_ATTACHMENT;
			case "99" -> MailSendingResponseStatus.TECHNICAL_ERROR;
			default -> MailSendingResponseStatus.UNKNOWN;
		};
	}

	public String getSchluessel() {
		return schluessel;
	}

	public String getMessage() {
		return message;
	}
}
