/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.apilib.vorgang.OzgCloudUserIdMapper;
import de.ozgcloud.nachrichten.common.grpc.NachrichtenCallContextAttachingInterceptor;

class NachrichtenManagerCallContextProviderTest {

	@InjectMocks
	private NachrichtenManagerCallContextProvider callContextProvider;

	@Mock
	private OzgCloudUserIdMapper userIdMapper;

	@Nested
	class TestProvideContext {

		@BeforeEach
		void init() {
			when(userIdMapper.toUserId(anyString())).thenReturn(
					OzgCloudUserId.from(NachrichtenCallContextAttachingInterceptor.NACHRICHTEN_MANAGER_SENDER_USER_ID));
		}

		@Test
		void shouldSetClientName() {
			var result = callContextProvider.provideContext();

			assertThat(result.getClientName()).isEqualTo(NachrichtenCallContextAttachingInterceptor.NACHRICHTEN_MANAGER_CLIENT_NAME);
		}

		@Test
		void shouldCallUserIdMapper() {
			callContextProvider.provideContext();

			verify(userIdMapper).toUserId(NachrichtenCallContextAttachingInterceptor.NACHRICHTEN_MANAGER_SENDER_USER_ID);
		}

		@Test
		void shouldSetUserId() {
			var result = callContextProvider.provideContext();

			assertThat(result.getUserId()).hasToString(NachrichtenCallContextAttachingInterceptor.NACHRICHTEN_MANAGER_SENDER_USER_ID);
		}
	}

}