/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten;

import org.mapstruct.factory.Mappers;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;

import de.ozgcloud.apilib.common.command.OzgCloudCommandService;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.vorgang.OzgCloudFileIdMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudUserIdMapper;
import de.ozgcloud.nachrichten.postfach.muk.MukPostfachConfiguration;

@SpringBootApplication
@ComponentScan(basePackages = "de.ozgcloud.*")
public class NachrichtenManagerTestApplication {

	@MockBean
	private OzgCloudCommandService ozgCloudCommandService;
	@MockBean
	@Qualifier(NachrichtenManagerConfiguration.OZG_CLOUD_FILE_SERVICE_NAME)
	private OzgCloudFileService nachrichtenOzgCloudFileServices;
	@MockBean
	@Qualifier(MukPostfachConfiguration.OZG_CLOUD_FILE_SERVICE_NAME)
	private OzgCloudFileService mukOzgCloudFileServices;


	@Bean
	OzgCloudFileIdMapper ozgCloudFileIdMapper() {
		return Mappers.getMapper(OzgCloudFileIdMapper.class);
	}

	@Bean
	OzgCloudUserIdMapper ozgCloudUserIdMapper() {
		return Mappers.getMapper(OzgCloudUserIdMapper.class);
	}
}
