/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.antragraum;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.opensaml.saml.saml2.core.Response;
import org.springframework.test.util.ReflectionTestUtils;

import de.ozgcloud.common.test.TestUtils;

class Saml2ParserTest {
	private BayernIdSamlConfiguration configuration;

	@BeforeEach
	void setup() {
		var properties = mock(AntragraumProperties.class);
		configuration = new BayernIdSamlConfiguration();
		ReflectionTestUtils.setField(configuration, "antragraumProperties", properties);
		configuration.initOpenSAML();
	}

	@Test
	void shouldInit() {
		var parser = new Saml2Parser(configuration);

		assertThat(parser).isNotNull();
	}

	@Test
	void shouldParseSamlToken() throws Exception {
		var response = getResponse();
		assertThat(response).isNotNull();
	}

	@Test
	void shouldHaveAssertions() throws Exception {
		var response = getResponse();
		assertThat(response.getAssertions()).isNotNull();
	}

	@Test
	void shouldHaveEncryptedAssertions() throws Exception {
		var response = getResponse();
		assertThat(response.getEncryptedAssertions()).isNotNull();
	}

	@Test
	void shouldHaveIssuer() throws Exception {
		var response = getResponse();
		assertThat(response.getIssuer().getValue()).isEqualTo("https://infra-pre-id.bayernportal.de/idp");
	}

	@Test
	void shouldGetXMLObject() throws Exception {
		var parser = new Saml2Parser(configuration);

		try (var tokenStream = TestUtils.loadFile("SamlResponse.xml")) {
			assertThat(parser.xmlObject(tokenStream)).isNotNull();
		}
	}

	private Response getResponse() throws Exception {
		var token = TestUtils.loadTextFile("SamlResponse.xml");
		var parser = new Saml2Parser(configuration);

		return parser.parse(token);
	}

}