/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.email;

import io.grpc.stub.StreamObserver;
import lombok.SneakyThrows;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.test.util.ReflectionTestUtils;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

class EmailGrpcServiceTest {

	@Mock
	private MailService mailService;

	@InjectMocks
	private EmailGrpcService emailGrpcService;

	@Nested
	@DisplayName("When called send email gRPC endpoint")
	class TestSendEmail {

		@Mock
		private StreamObserver<GrpcSendEmailResponse> streamObserver;
		@Captor
		private ArgumentCaptor<MailSendRequest> mailRequestCaptor;

		@BeforeEach
		@SneakyThrows
		public void init() {
			ReflectionTestUtils.setField(emailGrpcService, "mailFrom", MailSendRequestTestFactory.FROM);
		}

		@Test
		void shouldSendEmail() {
			var mailSendRequest = MailSendRequestTestFactory.createBuilder().clearToAddresses()
					.toAddress(MailSendRequestTestFactory.EMAIL_RECIPIENT).clearAttachments()
					.replyTo(null).requestReference(null).build();

			emailGrpcService.sendEmail(GrpcNotificationRecipientsTestFactory.create(), streamObserver);

			verify(mailService).sendMail(mailRequestCaptor.capture());
			assertThat(mailRequestCaptor.getValue()).usingRecursiveComparison().isEqualTo(mailSendRequest);
		}

		@Test
		void shouldSendAllEmail() {
			var request = GrpcNotificationRecipientsTestFactory.createBuilder().addRecipients(GrpcRecipientTestFactory.create()).build();

			emailGrpcService.sendEmail(request, streamObserver);

			verify(mailService, times(2)).sendMail(any());
		}

		@Test
		void shouldSendResponse() {
			var notification = GrpcNotificationRecipientsTestFactory.create();

			emailGrpcService.sendEmail(notification, streamObserver);

			verify(streamObserver, times(1)).onNext(GrpcSendEmailResponse.newBuilder().build());
		}

		@Test
		void shouldCloseObserver() {
			var notification = GrpcNotificationRecipientsTestFactory.create();

			emailGrpcService.sendEmail(notification, streamObserver);

			verify(streamObserver, times(1)).onCompleted();
		}
	}

}