/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.email;

import java.util.UUID;

import jakarta.mail.util.ByteArrayDataSource;

import de.ozgcloud.nachrichten.email.MailSendRequest.MailAttachment;

class MailSendRequestTestFactory {

	public static final String FROM = "from@mailinator.com";
	public static final String TO = "to@mailinator.com";

	public static final String SUBJECT = "The Subject";
	public static final String BODY = "Lorem ipsum";

	public static final String REFERENCE = UUID.randomUUID().toString();

	public static final String ATTACHMENT_NAME = "aFile";
	public static final String ATTACHMENT = "BINARY_BLAH";

	public static final String REPLY_TO = "replyTo@mailinator.com";

	public static final MailRecipient EMAIL_RECIPIENT = MailRecipientTestFactory.createBuilder().email(TO).build();

	public static final String EMAIL_ADDRESS_TEMPLATE = "%s %s <%s>";

	public static MailSendRequest create() {
		return createBuilder().build();
	}

	public static MailSendRequest.MailSendRequestBuilder createBuilder() {
		var ds = new ByteArrayDataSource(ATTACHMENT.getBytes(), "plain/text");
		ds.setName(ATTACHMENT_NAME);

		return MailSendRequest.builder()
				.fromAddress(FROM)
				.toAddress(EMAIL_RECIPIENT)
				.subject(SUBJECT)
				.body(BODY)
				.requestReference(REFERENCE)
				.attachment(MailAttachment.builder()
						.dataSource(ds)
						.build())
				.replyTo(REPLY_TO);
	}
}
