/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.email;

import static de.ozgcloud.nachrichten.email.MailSendRequestTestFactory.*;
import static org.assertj.core.api.Assertions.*;

import jakarta.mail.util.ByteArrayDataSource;
import jakarta.validation.Validation;
import jakarta.validation.Validator;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.NullAndEmptySource;

import de.ozgcloud.nachrichten.email.MailSendRequest.MailAttachment;

class MailSendRequestValidationTest {

	private final Validator validator = Validation.buildDefaultValidatorFactory().getValidator();

	@Nested
	class TestToAddressesValidation {
		@Test
		void shouldBeValid() {
			var request = MailSendRequestTestFactory.create();

			var violations = validator.validate(request);

			assertThat(violations).isEmpty();
		}

		@Test
		void shouldBeInvalidOnEmpty() {
			var request = MailSendRequestTestFactory.createBuilder().clearToAddresses().build();

			var violations = validator.validate(request);

			assertThat(violations).isNotEmpty();
		}

		@ParameterizedTest
		@NullAndEmptySource
		void shouldBeInvalidOnBlankRecipientEmail(String email) {
			var recipient = MailRecipientTestFactory.createBuilder()
					.email(email)
					.build();
			var request = MailSendRequestTestFactory.createBuilder().clearToAddresses().toAddress(recipient).build();

			var violations = validator.validate(request);

			assertThat(violations).isNotEmpty();
		}
	}
}
