/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.email;

import static org.junit.jupiter.api.Assertions.*;

import jakarta.validation.ConstraintViolationException;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.function.Executable;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.mock.mockito.MockBean;

import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextAttachingInterceptor;
import de.ozgcloud.common.test.ITCase;

@ITCase
class MailServiceITCase {

	@Autowired
	private MailService mailService;

	@MockBean
	private OzgCloudCallContextAttachingInterceptor interceptor;

	@MockBean
	private EmailGrpcService emailGrpcService;

	@Nested
	class TestSendMail {

		@Test
		void shouldThrowConstraintViolationException() {
			Executable callSendMailWithoutRecipients = () -> mailService
					.sendMail(MailSendRequestTestFactory.createBuilder().clearToAddresses().build());

			assertThrows(ConstraintViolationException.class, callSendMailWithoutRecipients);
		}

		@Test
		void shouldNotThrowException() {
			Executable callSendMailWithoutRecipients = () -> mailService
					.sendMail(MailSendRequestTestFactory.create());

			assertDoesNotThrow(callSendMailWithoutRecipients);
		}
	}
}
