/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.info;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.info.nachricht.GrpcNachricht;
import de.ozgcloud.info.nachricht.GrpcNewNachrichtReply;
import de.ozgcloud.info.nachricht.GrpcNewNachrichtRequest;
import de.ozgcloud.info.nachricht.NachrichtServiceGrpc.NachrichtServiceBlockingStub;

class InfoManagerRemoteServiceTest {

	@Spy
	@InjectMocks
	private InfoManagerRemoteService service;

	@Mock
	private NachrichtServiceBlockingStub nachrichtServiceStub;
	@Mock
	private InfomanagerNachrichtMapper nachrichtMapper;

	@Nested
	class TestSendNotification {

		private static final String INFO_MANAGER_STATUS = "status";

		@Mock
		private GrpcNewNachrichtRequest grpcRequest;
		@Mock
		private GrpcNewNachrichtReply grpcReply;

		@BeforeEach
		void setup() {
			doReturn(grpcRequest).when(service).buildNachrichtRequest(any());
			when(nachrichtServiceStub.saveNewNachricht(any())).thenReturn(grpcReply);
		}

		@Test
		void shouldCallGrpcClient() {
			sendNotification();

			verify(nachrichtServiceStub).saveNewNachricht(grpcRequest);
		}

		@Test
		void shouldReturnStatus() {
			when(grpcReply.getStatus()).thenReturn(INFO_MANAGER_STATUS);

			var status = sendNotification();

			assertThat(status).isEqualTo(INFO_MANAGER_STATUS);
		}

		private String sendNotification() {
			return service.sendNotification(InfoManagerRequestTestFactory.create());
		}
	}

	@Nested
	class TestBuildNachrichtRequest {

		@Mock
		private GrpcNachricht grpcNachricht;

		@BeforeEach
		void setup() {
			when(nachrichtMapper.toGrpc(any())).thenReturn(grpcNachricht);
		}

		@Test
		void shouldCallMapper() {
			var nachricht = InfoManagerRequestTestFactory.create();

			service.buildNachrichtRequest(nachricht);

			verify(nachrichtMapper).toGrpc(nachricht);
		}

		@Test
		void shouldSetNachricht() {
			var grpcRequest = service.buildNachrichtRequest(InfoManagerRequestTestFactory.create());

			assertThat(grpcRequest.getNachricht()).isEqualTo(grpcNachricht);
		}
	}
}