/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid;

import static de.ozgcloud.nachrichten.postfach.bayernid.BayernIdAttachmentTestFactory.*;
import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.nachrichten.file.AttachmentFile;
import de.ozgcloud.nachrichten.file.AttachmentFileService;
import de.ozgcloud.nachrichten.file.AttachmentFileTestFactory;
import de.ozgcloud.nachrichten.postfach.FileId;

class BayernIdAttachmentServiceTest {

	private static final FileId FILE_ID = FileId.from("42");

	@InjectMocks
	@Spy
	private BayernIdAttachmentService service;

	@Mock
	private AttachmentFileService attachmentFileService;

	@Nested
	class TestGetMessageAttachment {

		@Mock
		private AttachmentFile attachmentFile;
		@Mock
		private InputStream fileContent;
		@Mock
		private BayernIdAttachment bayernIdAttachment;

		@BeforeEach
		void init() {
			when(attachmentFileService.getFile(any())).thenReturn(attachmentFile);
			when(attachmentFileService.getFileContent(any())).thenReturn(fileContent);
			doReturn(bayernIdAttachment).when(service).buildBayernIdAttachment(any(), any());
		}

		@Test
		void shouldCallGetFile() {
			service.getMessageAttachment(FILE_ID);

			verify(attachmentFileService).getFile(FILE_ID);
		}

		@Test
		void shouldCallGetFileContent() {
			service.getMessageAttachment(FILE_ID);

			verify(attachmentFileService).getFileContent(FILE_ID);
		}

		@Test
		void shouldCallBuildBayernIdAttachment() {
			service.getMessageAttachment(FILE_ID);

			verify(service).buildBayernIdAttachment(attachmentFile, fileContent);
		}

		@Test
		void shouldReturnBayernIdAttachment() {
			var attachment = service.getMessageAttachment(FILE_ID);

			assertThat(attachment).isSameAs(bayernIdAttachment);
		}
	}

	@Nested
	class TestBuildBayernIdAttachment {

		@BeforeEach
		void setup() {
		}

		@Test
		void shouldSetFileName() {
			var attachment = buildBayernIdAttachment();

			assertThat(attachment.getFileName()).isEqualTo(BayernIdAttachmentTestFactory.FILENAME);
		}

		@Test
		void shouldSetContent() {
			var attachment = buildBayernIdAttachment();

			assertThat(attachment.getContent()).hasSameContentAs(new ByteArrayInputStream(CONTENT));
		}

		@Test
		void shouldSetContentType() {
			var attachment = buildBayernIdAttachment();

			assertThat(attachment.getContentType()).isEqualTo(BayernIdAttachmentTestFactory.CONTENT_TYPE);
		}

		private BayernIdAttachment buildBayernIdAttachment() {
			return service.buildBayernIdAttachment(AttachmentFileTestFactory.create(), getContentStream());
		}
	}
}