/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid;

import java.time.Instant;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.UUID;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;

import de.akdb.egov.bsp.nachrichten.IdentifikationNachrichtType;
import de.akdb.egov.bsp.nachrichten.SchluesseltabelleType;
import lombok.val;

class IdentifikationNachrichtTypeTestFactory {
	public static final XMLGregorianCalendar ERSTELLUNGSZEITPUNKT = now();
	public static final String NACHRICHTEN_ID = UUID.randomUUID().toString();

	private static XMLGregorianCalendar now() {
		try {
			val c = new GregorianCalendar();
			c.setTime(Date.from(Instant.now()));
			return DatatypeFactory.newInstance().newXMLGregorianCalendar(c);
		} catch (DatatypeConfigurationException e) {
			throw new RuntimeException(e);
		}
	}

	public static IdentifikationNachrichtType create() {
		IdentifikationNachrichtType identifikationNachrichtType = new IdentifikationNachrichtType();
		identifikationNachrichtType.setNachrichtenId(NACHRICHTEN_ID);
		identifikationNachrichtType.setErstellungszeitpunkt(ERSTELLUNGSZEITPUNKT);
		return identifikationNachrichtType;
	}
}
