/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.osi;

import java.util.List;
import java.util.stream.Collectors;

import de.ozgcloud.common.test.TestUtils;
import lombok.Builder;
import lombok.Singular;

public class MessageJsonReplyTestFactory {

	public static final MessageAttachment MESSAGE_ATTACHMENT = MessageAttachmentTestFactory.create();

	public static String create() {
		return createBuilder().build();
	}

	public static MessageJsonReply.MessageJsonReplyBuilder createBuilder() {
		return MessageJsonReply.builder()
				.messageId(MessageTestFactory.MESSAGE_ID)
				.postfachId(MessageTestFactory.POSTFACH_ID)
				.mailBody(MessageTestFactory.MAIL_BODY)
				.replyOption(MessageTestFactory.REPLY_OPTION)
				.subject(MessageTestFactory.SUBJECT)
				.vorgangId(MessageTestFactory.VORGANG_ID)
				.attachment(MESSAGE_ATTACHMENT);
	}

	@Builder
	private static class MessageJsonReply {

		private static final String REPLY_MESSAGE_JSON_TMPL = "reply-message-json.tmpl";

		private static final String ATTACHMENT_TMPL = """
				{
				  "fileName": "%s",
				  "content": "%s"
				}""";

		private String messageId;
		private String postfachId;
		private String mailBody;
		private ReplyOption replyOption;
		private String subject;
		private String vorgangId;
		@Singular
		private List<MessageAttachment> attachments;

		public static class MessageJsonReplyBuilder {

			public String build() {
				return TestUtils.loadTextFile(REPLY_MESSAGE_JSON_TMPL)
						.formatted(messageId, postfachId, mailBody, replyOption.toValue(), subject, vorgangId,
								buildAttachments());
			}

			public String buildAttachments() {
				return attachments.stream().map(attachment -> ATTACHMENT_TMPL.formatted(attachment.getFileName(), attachment.getContent()))
						.collect(Collectors.joining(","));
			}
		}
	}

}
