/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.osi;

import java.util.List;
import java.util.UUID;

import de.ozgcloud.nachrichten.postfach.osi.Message.EidasLevel;

public class MessageTestFactory {

	public static final String MESSAGE_ID = UUID.randomUUID().toString();
	public static final String POSTFACH_ID = UUID.randomUUID().toString();
	public static final String VORGANG_ID = UUID.randomUUID().toString();

	public static final String MAIL_BODY = "Body<br>String";
	public static final boolean IS_HTML = false;
	public static final ReplyOption REPLY_OPTION = ReplyOption.MANDATORY;
	public static final String SUBJECT = "Test Subject";

	public static final EidasLevel EIDAS_LEVEL = EidasLevel.MEDIUM;
	public static final boolean RECHTSVERBINDLICH = true;

	public static final List<MessageAttachment> ATTACHMENTS = List.of(MessageAttachmentTestFactory.create());

	public static Message create() {
		return createBuilder().build();
	}

	public static Message.MessageBuilder createBuilder() {
		return Message.builder()
				.messageId(MESSAGE_ID)
				.postfachId(POSTFACH_ID)
				.mailBody(MAIL_BODY)
				.isHtml(IS_HTML)
				.replyOption(REPLY_OPTION)
				.subject(SUBJECT)
				.vorgangId(VORGANG_ID)
				.eidasLevel(EIDAS_LEVEL)
				.rechtsverbindlich(RECHTSVERBINDLICH)
				.attachments(ATTACHMENTS);
	}
}
