/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.osi;

import static org.junit.jupiter.api.Assertions.*;

import jakarta.validation.ConstraintViolationException;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.NullAndEmptySource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.web.client.RestTemplate;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.nachrichten.email.EmailGrpcService;
import de.ozgcloud.nachrichten.postfach.PostfachAddressTestFactory;
import de.ozgcloud.nachrichten.postfach.PostfachNachrichtTestFactory;
import de.ozgcloud.nachrichten.postfach.StringBasedIdentifierTestFactory;

@ITCase
@SpringBootTest(properties = {
		"ozgcloud.osi.postfach.proxyapi.url = foo",
		"ozgcloud.osi.postfach.proxyapi.key = bar",
		"ozgcloud.osi.postfach.proxyapi.realm = foobar"
})
class OsiPostfachRemoteServiceITCase {

	@Autowired
	private OsiPostfachRemoteService service;

	@MockBean
	private EmailGrpcService emailGrpcService;
	@MockBean
	private OsiPostfachProperties properties;
	@MockBean
	private RestTemplate restTemplate;

	@Nested
	class TestSendMessage {

		@ParameterizedTest
		@NullAndEmptySource
		void shouldThrowConstraintViolationExceptionOnMissingKontoType(String serviceKontoType) {
			var nachricht = PostfachNachrichtTestFactory.createBuilder()
					.postfachAddress(PostfachAddressTestFactory.createBuilder().serviceKontoType(serviceKontoType).build())
					.build();

			assertThrows(ConstraintViolationException.class, () -> service.sendMessage(nachricht));
		}

		@ParameterizedTest
		@NullAndEmptySource
		void shouldThrowConstraintViolationExceptionOnMissingIdentifier(String postfachId) {
			var postfachAddress = PostfachAddressTestFactory.createBuilder()
					.identifier(StringBasedIdentifierTestFactory.createBuilder().postfachId(postfachId).build())
					.build();
			var nachricht = PostfachNachrichtTestFactory.createBuilder()
					.postfachAddress(postfachAddress)
					.build();

			assertThrows(ConstraintViolationException.class, () -> service.sendMessage(nachricht));
		}
	}
}